﻿//------------------------------------------------------------------------------
//
// Sample test class for AS2Unit
//
// A simple test class with basic testing functionality of the AS2Unit framework.
//
// Alistair McLeod
// amcleod@iterationtwo.co.uk
//
// (c) 2003 iteration::two Ltd
//
//------------------------------------------------------------------------------

import com.iterationtwo.Money;
import as2unit.framework.TestCase;

class test.com.iterationtwo.TestMoney extends TestCase
{
	public function TestMoney( methodName:String )
	{
		super( methodName );
	}

//------------------------------------------------------------------------------

	public function testCreateMoney()
	{
		var pounds:Number = 10;
		var pence:Number = 0;

		var money:Money = new Money( pounds, pence );

		assertNotNull( money );
		assertNotUndefined( money );

		assertEquals( 10, money.pounds );
		assertEquals( 0, money.pence );
	}

//------------------------------------------------------------------------------

	public function testCreateMoneyMoreThan100Pence()
	{
		var pounds:Number = 4;
		var pence:Number = 120;

		var money:Money = new Money( pounds, pence );

		assertNotNull( "money was null", money );
		assertNotUndefined( "money was undefined", money );

		assertEquals( 5, money.pounds );
		assertEquals( 20, money.pence );
	}

//------------------------------------------------------------------------------

	public function testCreateMoneyBadConstruction()
	{
		var e:Error;
		var exceptionThrown:Boolean = false;
		try
		{
			var money:Money = new Money();
		}
		catch ( e:Error )
		{
			exceptionThrown = true;
		}
		if ( !exceptionThrown )
		   fail( "Exception should have been thrown" );
	}

//------------------------------------------------------------------------------

	public function testAddMoney()
	{
		var pounds1:Number = 3;
		var pence1:Number = 50;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 20;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.addMoney( money2 )

		assertNotNull( "money was null", money3 );
		assertNotUndefined( "money was undefined", money3 );

		assertEquals( "Pounds should be 6", 6, money3.pounds );
		assertEquals( "Pence should be 70", 70, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testAddMoneyCarryOverPence()
	{
		var pounds1:Number = 3;
		var pence1:Number = 50;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 60;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.addMoney( money2 )

		assertEquals( 7, money3.pounds );
		assertEquals( 10, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testAddMoneyMoreThan100Pence()
	{
		var pounds1:Number = 3;
		var pence1:Number = 150;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 160;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.addMoney( money2 )

		assertEquals( 9, money3.pounds );
		assertEquals( 10, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testSubtractMoney()
	{
		var pounds1:Number = 3;
		var pence1:Number = 50;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 2;
		var pence2:Number = 20;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.subtractMoney( money2 )

		assertEquals( 1, money3.pounds );
		assertEquals( 30, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testSubtractMoneyCarryOverPence()
	{
		var pounds1:Number = 3;
		var pence1:Number = 50;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 2;
		var pence2:Number = 80;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.subtractMoney( money2 )

		assertEquals( 0, money3.pounds );
		assertEquals( 70, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testSubtractMoneyMoreThan100Pence()
	{
		var pounds1:Number = 8;
		var pence1:Number = 150;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 260;
		var money2:Money = new Money( pounds2, pence2 );

		var money3:Money = money1.subtractMoney( money2 )

		assertEquals( 3, money3.pounds );
		assertEquals( 90, money3.pence );
	}

//------------------------------------------------------------------------------

	public function testSubtractResultLessThanZero()
	{
		var pounds1:Number = 1;
		var pence1:Number = 30;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 1;
		var pence2:Number = 50;
		var money2:Money = new Money( pounds2, pence2 );

		var e:Error;
		var exceptionThrown:Boolean = false;
		try
		{
			var money3:Money = money1.subtractMoney( money2 );
		}
		catch ( e:Error )
		{
			exceptionThrown = true;
		}
		if ( !exceptionThrown )
		   fail( "Exception should have been thrown" );
	}

//------------------------------------------------------------------------------

	public function testGreaterThan()
	{
		var pounds1:Number = 3;
		var pence1:Number = 20;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 21;
		var money2:Money = new Money( pounds2, pence2 );

		assertTrue( "money2 should be greater than money1", money2.greaterThan( money1 ) );
		assertFalse( "money1 should not be greater than money2", money1.greaterThan( money2 ) );
	}

//------------------------------------------------------------------------------

	public function testLessThan()
	{
		var pounds1:Number = 3;
		var pence1:Number = 20;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 19;
		var money2:Money = new Money( pounds2, pence2 );

		assertTrue( "money2 should be less than money1", money2.lessThan( money1 ) );
		assertFalse( "money1 should not be less than money2", money1.lessThan( money2 ) );
	}

//------------------------------------------------------------------------------

	public function testEquals()
	{
		var pounds1:Number = 3;
		var pence1:Number = 20;
		var money1:Money = new Money( pounds1, pence1 );

		var pounds2:Number = 3;
		var pence2:Number = 20;
		var money2:Money = new Money( pounds2, pence2 );

		assertTrue( "money1 and money2 should be equal", money2.equals( money1 ) );
	}
}